@@ -12,7 +12,7 @@ from astro.utils.task_id_helper import get_task_id
 
 
 class LoadFile(BaseOperator):
-    """Load S3/local table to postgres/snowflake database
+    """Load S3/local file into either a database or a pandas dataframe
 
     :param input_file: File path and conn_id for object stores
     :param output_table: Table to create
@@ -78,7 +78,9 @@ class LoadFile(BaseOperator):
         )
         if_exists = self.if_exists
         for file in get_files(
-            input_file.path, input_file.conn_id, normalize_config=self.normalize_config
+            input_file.path,
+            input_file.conn_id,
+            normalize_config=self.normalize_config,
         ):
             database.load_pandas_dataframe_to_table(
                 source_dataframe=file.export_to_dataframe(),
@@ -96,7 +98,10 @@ class LoadFile(BaseOperator):
         SQL table was specified
         """
         df = None
-        for file in get_files(input_file.path, input_file.conn_id):
+        for file in get_files(
+            input_file.path,
+            input_file.conn_id,
+        ):
             if isinstance(df, pd.DataFrame):
                 df = pd.concat([df, file.export_to_dataframe()])
             else:
@@ -155,7 +160,8 @@ def load_file(
     ndjson_normalize_sep: str = "_",
     **kwargs: Any,
 ) -> XComArg:
-    """Convert LoadFile into a function that Returns an XComArg object
+    """Load a file or bucket into either a SQL table or a pandas dataframe.
+
     :param input_file: File path and conn_id for object stores
     :param output_table: Table to create
     :param task_id: task id, optional
